#!/bin/sh
#
# ================================================================
# Licensed Material - Property of IBM                                        
# 5655-P28 Copyright IBM Corp. 2006, 2007                               
#                                                                            
# All Rights Reserved.                                                       
#                                                                            
# U.S. Government users - RESTRICTED RIGHTS - Use, Duplication, or           
# Disclosure restricted by GSA-ADP schedule contract with IBM Corp.          
#                                                                            
# Status = HEEX610           
# ================================================================
#                                                                            
# remove wxd base install code
# usage: <name>.sh <install hfs location> <configuration hfs location
#
 
if [ -z $1 ]
then
   echo "Syntax: <name>.sh <install hfs location> <(Writable) configuration hfs location>"
   exit 0
fi
 
if [ -z $2 ]
then
   echo "Syntax: <name>.sh <install hfs location> <(Writable) configuration hfs location>"
   exit 0
fi
 
InstallRoot=$1
ConfigRoot=$2
 
if [ ! -d $InstallRoot ]
then
   echo "$InstallRoot is not a valid directory"
   echo "Syntax: <name>.sh <install hfs location> <(Writable) configuration hfs location>"
   exit 0
fi
 
if [ ! -d $ConfigRoot ]
then
   echo "$ConfigRoot is not a valid directory"
   echo "Syntax: <name>.sh <install hfs location> <(Writable) configuration hfs location>"
   exit 0
fi
 
if [ ! -w $ConfigRoot ]
then
   echo "$ConfigRoot must be writable"
   echo "Syntax: <name>.sh <install hfs location> <(Writable) configuration hfs location>"
   exit 0
fi
 
#
# check that the <config_root>/etc directory is not a symbolic link
#
 
if [ -h $ConfigRoot/etc ]
then
   echo "$ConfigRoot/etc directory must be writable"
   echo "Further configuration aborted"
   exit 1
  
 
fi

echo "wsadmin.sh issued to delete the xd portlet"
$ConfigRoot/bin/wsadmin.sh -lang jython -conntype none -c "AdminApp.update('isclite', 'modulefile', '[-operation delete -contenturi xdportlet.war]')"


AllFilesToUnlink="$ConfigRoot/properties/version/WXD.registrar
$ConfigRoot/bin/checkDWLMLocation.jacl		 		  
$ConfigRoot/bin/Create61.py		 		  
$ConfigRoot/bin/createXDAgentPorts.py		 		  
$ConfigRoot/bin/dumpNewBB.py		 		  
$ConfigRoot/bin/eexaugment.sh		 		  
$ConfigRoot/bin/eexfinal.sh		 		  
$ConfigRoot/bin/eexrmsymlnk.sh		 		  
$ConfigRoot/bin/eexsync.sh		 		  
$ConfigRoot/bin/eexwpost.sh		 		  
$ConfigRoot/bin/Extractor.bat		 		  
$ConfigRoot/bin/Extractor.sh		 		  
$ConfigRoot/bin/manageODC.py		 		  
$ConfigRoot/bin/MirrorCell.bat		 		  
$ConfigRoot/bin/MirrorCell.sh		 		  
$ConfigRoot/bin/mwServerStatus.sh		 		  
$ConfigRoot/bin/pluginMerge.bat		 		  
$ConfigRoot/bin/pluginMerge.sh		 		  
$ConfigRoot/bin/Read51.py		 		  
$ConfigRoot/bin/Rules.xml		 		  
$ConfigRoot/bin/startMWServer.sh		 		  
$ConfigRoot/bin/stopMWServer.sh		 		  
$ConfigRoot/bin/xd_migration.sh		 		  
$ConfigRoot/bin/xd_migration/migrationGUI/xd_migrationGUI.jar		 		  
$ConfigRoot/bin/xdaSetupCmdLine.sh		 		  
$ConfigRoot/bin/XDPreUpgrade.sh		 		  
$ConfigRoot/bin/XDUpgrade.sh		 		  
$ConfigRoot/etc/config/xforms/wxdcg/compatibility.xml		 		  
$ConfigRoot/etc/config/xforms/wxdcg/noproduct/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/wxdcg/noproduct/transformMetadata.xml		 		  
$ConfigRoot/etc/config/xforms/wxddg/compatibility.xml		 		  
$ConfigRoot/etc/config/xforms/wxddg/noproduct/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/wxddg/noproduct/transformMetadata.xml		 		  
$ConfigRoot/etc/config/xforms/wxdop/compatibility.xml		 		  
$ConfigRoot/etc/config/xforms/wxdop/noproduct/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/wxdop/noproduct/transformMetadata.xml		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/autonomicrequestflowmanager.xsl		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/copy.xsl		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/gridscheduler.xsl		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/healthclass.xsl		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/serviceclass.xsl		 		  
$ConfigRoot/etc/config/xforms/xd/6.0.2.x/transformMetadata.xml		 		  
$ConfigRoot/etc/config/xforms/xd/compatibility.xml		 		  
$ConfigRoot/etc/config/xforms/xd/noproduct/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/xd/noproduct/transformMetadata.xml		 		  
$ConfigRoot/etc/config/xforms/xda/compatibility.xml		 		  
$ConfigRoot/etc/config/xforms/xda/noproduct/namespace-transforms.xml		 		  
$ConfigRoot/etc/config/xforms/xda/noproduct/transformMetadata.xml		 		  
$ConfigRoot/firststeps/XD/html/bannerfirststeps.jpg		 		  
$ConfigRoot/firststeps/XD/html/firststeps.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_ko_KR.css		 		  
$ConfigRoot/firststeps/XD/html/firststeps_noadmin.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_nopmt.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_nopmt_noadmin.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_stop.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_stop_noadmin.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_stop_nopmt.html		 		  
$ConfigRoot/firststeps/XD/html/firststeps_stop_nopmt_noadmin.html		 		  
$ConfigRoot/firststeps/XD/html/ws16x16.gif		 		  
$ConfigRoot/lib/asyncpmiclient.jar		 		  
$ConfigRoot/lib/asyncpmihelpers.jar		 		  
$ConfigRoot/lib/bbson.jar		 		  
$ConfigRoot/lib/bbsonapi.jar		 		  
$ConfigRoot/lib/bbsonservices.jar		 		  
$ConfigRoot/lib/classify.jar		 		  
$ConfigRoot/lib/configParsers.jar		 		  
$ConfigRoot/lib/css.jar		 		  
$ConfigRoot/lib/dwlm.jar		 		  
$ConfigRoot/lib/expr.jar		 		  
$ConfigRoot/lib/extnode.jar		 		  
$ConfigRoot/lib/giop.filter.jar		 		  
$ConfigRoot/lib/giop.threadpool.jar		 		  
$ConfigRoot/lib/gridendpointsensor.comm.jar		 		  
$ConfigRoot/lib/gridutility.jar		 		  
$ConfigRoot/lib/hamanageditem.jar		 		  
$ConfigRoot/lib/hamanageradtech.jar		 		  
$ConfigRoot/lib/jlanclient.jar		 		  
$ConfigRoot/lib/JSON4J.jar		 		  
$ConfigRoot/lib/legacycell.jar		 		  
$ConfigRoot/lib/libNodeDetect.so		 		  
$ConfigRoot/lib/libProcessCPU.so		 		  
$ConfigRoot/lib/membershippolicy.jar		 		  
$ConfigRoot/lib/nodedetect.jar		 		  
$ConfigRoot/lib/nodedetectp2p.jar		 		  
$ConfigRoot/lib/odcnd.jar		 		  
$ConfigRoot/lib/odcxd.jar		 		  
$ConfigRoot/lib/p2pcommon.jar		 		  
$ConfigRoot/lib/p2podc.jar		 		  
$ConfigRoot/lib/placement.algorithms.jar		 		  
$ConfigRoot/lib/placement.bizgrid.jar		 		  
$ConfigRoot/lib/pmiasyncserver.jar		 		  
$ConfigRoot/lib/remoteaccess.jar		 		  
$ConfigRoot/lib/rxa-langpack.jar		 		  
$ConfigRoot/lib/serverInfo.jar		 		  
$ConfigRoot/lib/ssh.jar		 		  
$ConfigRoot/lib/wccm.xd.common.jar		 		  
$ConfigRoot/lib/wccm.xd.jar		 		  
$ConfigRoot/lib/wsmmcore.jar		 		  
$ConfigRoot/lib/wsson.jar		 		  
$ConfigRoot/lib/xd_htmlshell.jar		 		  
$ConfigRoot/lib/xd_htmlshell.v7.jar		 		  
$ConfigRoot/lib/xdaconfig.jar		 		  
$ConfigRoot/lib/xdadiscoveryrpc.jar		 		  
$ConfigRoot/lib/xdagentapi.jar		 		  
$ConfigRoot/lib/xdagentcatalogservice.jar		 		  
$ConfigRoot/lib/xdagentdiscoveryservice.jar		 		  
$ConfigRoot/lib/xdagentfileservice.jar		 		  
$ConfigRoot/lib/xdagenthttpservice.jar		 		  
$ConfigRoot/lib/xdagentkernel.jar		 		  
$ConfigRoot/lib/xdagentnodeservice.jar		 		  
$ConfigRoot/lib/xdagentodc.jar		 		  
$ConfigRoot/lib/xdagentphpservice.jar		 		  
$ConfigRoot/lib/xdagentprocessmgmt.jar		 		  
$ConfigRoot/lib/xdagentreposservice.jar		 		  
$ConfigRoot/lib/xdagentsession.jar		 		  
$ConfigRoot/lib/xdagentutils.jar		 		  
$ConfigRoot/lib/xdamessages.jar		 		  
$ConfigRoot/lib/xdarpcserv.jar		 		  
$ConfigRoot/lib/xdasecurity.jar		 		  
$ConfigRoot/lib/xdawascomponent.jar		 		  
$ConfigRoot/lib/xdawasinterface.jar		 		  
$ConfigRoot/lib/xdcimgr.jar		 		  
$ConfigRoot/lib/xdcomm.jar		 		  
$ConfigRoot/lib/xdmigrationresources.jar		 		  
$ConfigRoot/lib/xdmigrationutils.jar		 		  
$ConfigRoot/lib/xdoperations.jar		 		  
$ConfigRoot/lib/xdpreupgrade.jar		 		  
$ConfigRoot/lib/xdupgrade.jar		 		  
$ConfigRoot/lib/xdutils.jar		 		  
$ConfigRoot/license.xd/LA_cs		 		  
$ConfigRoot/license.xd/LA_cs.txt		 		  
$ConfigRoot/license.xd/LA_de		 		  
$ConfigRoot/license.xd/LA_de.txt		 		  
$ConfigRoot/license.xd/LA_en		 		  
$ConfigRoot/license.xd/LA_en.txt		 		  
$ConfigRoot/license.xd/LA_es		 		  
$ConfigRoot/license.xd/LA_es.txt		 		  
$ConfigRoot/license.xd/LA_fr		 		  
$ConfigRoot/license.xd/LA_fr.txt		 		  
$ConfigRoot/license.xd/LA_it		 		  
$ConfigRoot/license.xd/LA_it.txt		 		  
$ConfigRoot/license.xd/LA_ja		 		  
$ConfigRoot/license.xd/LA_ja.txt		 		  
$ConfigRoot/license.xd/LA_ko		 		  
$ConfigRoot/license.xd/LA_ko.txt		 		  
$ConfigRoot/license.xd/LA_pl		 		  
$ConfigRoot/license.xd/LA_pl.txt		 		  
$ConfigRoot/license.xd/LA_pt		 		  
$ConfigRoot/license.xd/LA_pt.txt		 		  
$ConfigRoot/license.xd/LA_tr		 		  
$ConfigRoot/license.xd/LA_tr.txt		 		  
$ConfigRoot/license.xd/LA_zh		 		  
$ConfigRoot/license.xd/LA_zh.txt		 		  
$ConfigRoot/license.xd/LA_zh_TW		 		  
$ConfigRoot/license.xd/LA_zh_TW.txt		 		  
$ConfigRoot/license.xd/LI_cs		 		  
$ConfigRoot/license.xd/LI_cs.txt		 		  
$ConfigRoot/license.xd/LI_de		 		  
$ConfigRoot/license.xd/LI_de.txt		 		  
$ConfigRoot/license.xd/LI_en		 		  
$ConfigRoot/license.xd/LI_en.txt		 		  
$ConfigRoot/license.xd/LI_es		 		  
$ConfigRoot/license.xd/LI_es.txt		 		  
$ConfigRoot/license.xd/LI_fr		 		  
$ConfigRoot/license.xd/LI_fr.txt		 		  
$ConfigRoot/license.xd/LI_it		 		  
$ConfigRoot/license.xd/LI_it.txt		 		  
$ConfigRoot/license.xd/LI_ja		 		  
$ConfigRoot/license.xd/LI_ja.txt		 		  
$ConfigRoot/license.xd/LI_ko		 		  
$ConfigRoot/license.xd/LI_ko.txt		 		  
$ConfigRoot/license.xd/LI_pl		 		  
$ConfigRoot/license.xd/LI_pl.txt		 		  
$ConfigRoot/license.xd/LI_pt		 		  
$ConfigRoot/license.xd/LI_pt.txt		 		  
$ConfigRoot/license.xd/LI_tr		 		  
$ConfigRoot/license.xd/LI_tr.txt		 		  
$ConfigRoot/license.xd/LI_zh		 		  
$ConfigRoot/license.xd/LI_zh.txt		 		  
$ConfigRoot/license.xd/LI_zh_TW		 		  
$ConfigRoot/license.xd/LI_zh_TW.txt		 		  
$ConfigRoot/plugins/com.ibm.ws.xd.admin.extension_6.1.0.jar		 		  
$ConfigRoot/plugins/com.ibm.ws.xd.nodedetect.metadata_6.1.0.jar		 		  
$ConfigRoot/plugins/com.ibm.ws.xd.nodedetect.p2p.metadata_6.1.0.jar		 		  
$ConfigRoot/properties/ce_2.0.xml		 		  
$ConfigRoot/properties/ce_2.0_repo.xml		 		  
$ConfigRoot/properties/ce_2.1.xml		 		  
$ConfigRoot/properties/ce_2.1_repo.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/de/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.centralizedinstallmanager.validation.CentralizedInstallManagerValidation.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.healthpolicy.validation.healthclassvalidationNLS.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.servicepolicy.validation.policyvalidationNLS.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.websphere.models.config.wpfhttp.validation.partitionsvalidationNLS.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.admin.extension.mixedcellNLS.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/en/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/es/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/fr/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/it/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/ja/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/ko/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/pt_BR/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/zh/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.son.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.websphere.models.config.dynamiccluster.validation.dynamicclustervalidationNLS.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.websphere.models.config.wpfhttp.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.classify.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.csservices.resources.css.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.dwlm.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.expr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.externalnode.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.giop.threadpool.resources.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.odc.nd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.odc.xd.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.serverinfo.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.wsgroup.p2p.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.agent.resources.messages.xda.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.agent.ssl.resources.ssl.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.cimgr.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.grid.agent.nls.Messages.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.migration.resources.XDUpgrade.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.nodedetect.p2p.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.nodedetect.resources.nodedetect.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.pmi.async.client.resources.asyncpmiclient.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.pmi.async.helpers.resources.asyncpmihelpers.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.ws.xd.pmi.async.server.resources.asyncpmiserver.xml		 		  
$ConfigRoot/properties/messages/zh_TW/com.ibm.wsmm.nls.Messages.xml		 		  
$ConfigRoot/properties/version/admin.config.base390.component		 		  
$ConfigRoot/properties/version/admin.config.base390.postinstall.component		 		  
$ConfigRoot/properties/version/admin.config.base390.postinstall.zos.unspecified.component		 		  
$ConfigRoot/properties/version/admin.config.base390.zos.unspecified.component		 		  
$ConfigRoot/properties/version/admin.config390.common.component		 		  
$ConfigRoot/properties/version/admin.config390.common.zos.unspecified.component		 		  
$ConfigRoot/properties/version/apache.util.component		 		  
$ConfigRoot/properties/version/async.pmi.client.component		 		  
$ConfigRoot/properties/version/async.pmi.helpers.component		 		  
$ConfigRoot/properties/version/async.pmi.server.component		 		  
$ConfigRoot/properties/version/bbson.api.component		 		  
$ConfigRoot/properties/version/bbson.component		 		  
$ConfigRoot/properties/version/bbson.services.component		 		  
$ConfigRoot/properties/version/classify.component		 		  
$ConfigRoot/properties/version/dwlm.component		 		  
$ConfigRoot/properties/version/expr.component		 		  
$ConfigRoot/properties/version/extnode.component		 		  
$ConfigRoot/properties/version/firststeps.xd.component		 		  
$ConfigRoot/properties/version/firststeps.xd.unix.unspecified.component		 		  
$ConfigRoot/properties/version/giop.filter.component		 		  
$ConfigRoot/properties/version/giop.threadpool.component		 		  
$ConfigRoot/properties/version/grid.endpointsensor.comm.component		 		  
$ConfigRoot/properties/version/grid.utility.component		 		  
$ConfigRoot/properties/version/hamanageditem.component		 		  
$ConfigRoot/properties/version/hamanager.adtech.component		 		  
$ConfigRoot/properties/version/install.xd.migrationgui.component		 		  
$ConfigRoot/properties/version/install.xd.migrationgui.unix.unspecified.component		 		  
$ConfigRoot/properties/version/install.xd.uninstall.component		 		  
$ConfigRoot/properties/version/install.xd/firststeps/firststeps.sh		 		  
$ConfigRoot/properties/version/install.xd/firststeps/firststeps.was7.sh		 		  
$ConfigRoot/properties/version/install.zos.specific.component		 		  
$ConfigRoot/properties/version/install.zos.specific.zos.unspecified.component		 		  
$ConfigRoot/properties/version/legal.xd.component		 		  
$ConfigRoot/properties/version/membershippolicy.component		 		  
$ConfigRoot/properties/version/nif/componentmaps.xd/componentmap.xd.common.dir.xml		 		  
$ConfigRoot/properties/version/nif/componentmaps.xd/componentmap.xd.common.was.xml		 		  
$ConfigRoot/properties/version/nif/componentmaps.xd/componentmap.xd.common.xml		 		  
$ConfigRoot/properties/version/nif/config.xd/install/97SconfigNoXDProfileFirstSteps.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/97SdeleteNoXDProfileFirstSteps.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/97SStopDefaultServers.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/97SStopNodes.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/98SStopDmgrs.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/99SrunISCDeployRestore.ant		 		  
$ConfigRoot/properties/version/nif/config.xd/uninstall/99SuninstallAdditionalFiles.ant		 		  
$ConfigRoot/properties/version/nodedetect.component		 		  
$ConfigRoot/properties/version/nodedetect.natv.component		 		  
$ConfigRoot/properties/version/nodedetect.natv.zos.unspecified.component		 		  
$ConfigRoot/properties/version/nodedetect.p2p.component		 		  
$ConfigRoot/properties/version/odc.nd.component		 		  
$ConfigRoot/properties/version/odc.xd.component		 		  
$ConfigRoot/properties/version/p2p.common.component		 		  
$ConfigRoot/properties/version/p2podc.component		 		  
$ConfigRoot/properties/version/placement.algorithms.component		 		  
$ConfigRoot/properties/version/placement.bizgrid.component		 		  
$ConfigRoot/properties/version/pmi.processCPU.component		 		  
$ConfigRoot/properties/version/pmi.processCPU.zos.unspecified.component		 		  
$ConfigRoot/properties/version/prereq.rxa.component		 		  
$ConfigRoot/properties/version/serverinfo.component		 		  
$ConfigRoot/properties/version/wccm.xd.common.component		 		  
$ConfigRoot/properties/version/wccm.xd.component		 		  
$ConfigRoot/properties/version/webui.xd.common.component		 		  
$ConfigRoot/properties/version/wsmm-core.component		 		  
$ConfigRoot/properties/version/wsson.component		 		  
$ConfigRoot/properties/version/WXDBASE.product		 		  
$ConfigRoot/properties/version/xd.admin.cimgr.component		 		  
$ConfigRoot/properties/version/xd.css.component		 		  
$ConfigRoot/properties/version/xd.legacycell.management.component		 		  
$ConfigRoot/properties/version/xd.migration.component		 		  
$ConfigRoot/properties/version/xd.migration.resources.component		 		  
$ConfigRoot/properties/version/xd.migration.unix.unspecified.component		 		  
$ConfigRoot/properties/version/xd.migration.utils.component		 		  
$ConfigRoot/properties/version/xd.mixedcell.component		 		  
$ConfigRoot/properties/version/xd.premigrate.component		 		  
$ConfigRoot/properties/version/xd.premigrate.unix.unspecified.component		 		  
$ConfigRoot/properties/version/xd.utils.component		 		  
$ConfigRoot/properties/version/xdagent.api.component		 		  
$ConfigRoot/properties/version/xdagent.catalogservice.component		 		  
$ConfigRoot/properties/version/xdagent.config.component		 		  
$ConfigRoot/properties/version/xdagent.discovery.rpcservice.component		 		  
$ConfigRoot/properties/version/xdagent.discoveryservice.component		 		  
$ConfigRoot/properties/version/xdagent.fileservice.component		 		  
$ConfigRoot/properties/version/xdagent.httpservice.component		 		  
$ConfigRoot/properties/version/xdagent.kernel.component		 		  
$ConfigRoot/properties/version/xdagent.nodeservice.component		 		  
$ConfigRoot/properties/version/xdagent.odc.component		 		  
$ConfigRoot/properties/version/xdagent.phpservice.component		 		  
$ConfigRoot/properties/version/xdagent.prereq.jsontools.component		 		  
$ConfigRoot/properties/version/xdagent.processmgt.component		 		  
$ConfigRoot/properties/version/xdagent.reposservice.component		 		  
$ConfigRoot/properties/version/xdagent.resources.component		 		  
$ConfigRoot/properties/version/xdagent.rpcservice.component		 		  
$ConfigRoot/properties/version/xdagent.scripts.component		 		  
$ConfigRoot/properties/version/xdagent.scripts.unix.unspecified.component		 		  
$ConfigRoot/properties/version/xdagent.security.component		 		  
$ConfigRoot/properties/version/xdagent.session.component		 		  
$ConfigRoot/properties/version/xdagent.utils.component		 		  
$ConfigRoot/properties/version/xdagent.was.component.component		 		  
$ConfigRoot/properties/version/xdagent.was.interface.component		 		  
$ConfigRoot/properties/version/xdagent.was.middlewarerpcservices.component		 		  
$ConfigRoot/properties/version/xdcomm.component		 		  
$ConfigRoot/properties/version/xdoperations.component		 		  
$ConfigRoot/properties/WXD/WXDPREUPGRADE/6.1.0.0/config/create/actions/1FBackUpProfileConfig.ant		 		  
$ConfigRoot/properties/WXD/WXDPREUPGRADE/6.1.0.0/config/remove/actions/1FRemoveProfileBackUp.ant		 		  
$ConfigRoot/properties/xdagentcomp.props		 		  
$ConfigRoot/properties/xservices.props		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/build.txt		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/dojo.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/iframe_history.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/LICENSE		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/README		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/a11y.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/AdapterRegistry.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation/Animation.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation/AnimationEvent.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation/AnimationSequence.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/animation/Timer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/behavior.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/bootstrap1.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/bootstrap2.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/browser_debug.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/cal/iCalendar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/cal/textDirectory.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/Axis.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/Chart.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/Plot.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/PlotArea.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/Plotters.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/README.txt		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/Series.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/svg/Axis.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/svg/PlotArea.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/svg/Plotters.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/vml/Axis.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/vml/PlotArea.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/charting/vml/Plotters.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/ArrayList.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/BinaryTree.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Collections.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Dictionary.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Graph.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Queue.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Set.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/SkipList.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/SortedList.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Stack.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/collections/Store.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/crypto.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/core/Read.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/core/RemoteStore.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/core/Result.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/core/Write.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/CsvStore.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Attribute.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/format/Csv.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/format/Json.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Item.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Kind.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Observable.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/provider/Base.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/provider/Delicious.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/provider/FlatFile.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/provider/JotSpot.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/provider/MySql.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/ResultSet.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/to_do.txt		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Type.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/old/Value.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/OpmlStore.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/RdfStore.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/data/YahooStore.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/date.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/date/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/date/format.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/date/serialize.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/date/supplemental.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/arrow_hide.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/arrow_show.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/console.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/deep.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/Firebug.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/debug/spacer.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/Deferred.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/DeferredList.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/DragAndDrop.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/HtmlDragAndDrop.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/HtmlDragCopy.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/HtmlDragManager.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/HtmlDragMove.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/Sortable.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/TreeDragAndDrop.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dnd/TreeDragAndDropV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/docs.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/dom.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/event.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/event/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/event/browser.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/event/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/event/topic.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/experimental.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/flash.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/flash/flash6/DojoExternalInterface.as		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/flash/flash6/flash6_gateway.fla		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/flash/flash8/DojoExternalInterface.as		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/flash/flash8/ExpressInstall.as		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/color.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/color/hsl.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/color/hsv.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/Colorspace.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/matrix.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/path.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/shape.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/svg.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/gfx/vml.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/graphics/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/graphics/color.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/graphics/color/hsl.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/graphics/color/hsv.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/graphics/Colorspace.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_adobesvg.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_browser.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_dashboard.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_jsc.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_rhino.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_spidermonkey.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_svg.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/hostenv_wsh.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/color.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/display.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/iframe.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowB.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowBL.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowBR.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowL.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowR.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowT.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowTL.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/images/shadowTR.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/layout.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/metrics.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/selection.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/shadow.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/style.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/html/util.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/de/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/en/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/es/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/fi/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/fr/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/gregorianExtras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/hu/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/it/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/ja/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/ja/gregorianExtras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/ko/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/nl/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/pt/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/pt-br/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/README		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/sv/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/zh/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/zh/gregorianExtras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/zh-cn/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/zh-hk/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/calendar/nls/zh-tw/gregorian.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/EUR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/GBP.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/INR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/ITL.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/JPY.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en/USD.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/en-us/USD.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/EUR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/GBP.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/EUR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/GBP.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/INR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/ITL.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/JPY.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/hi/USD.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/INR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ITL.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/EUR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/GBP.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/INR.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/ITL.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/JPY.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/ja/USD.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/JPY.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/README		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/currency/nls/USD.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/i18n/number.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/iCalendar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/BrowserIO.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/cometd.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/cookie.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/IframeIO.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/RepubsubIO.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/RhinoIO.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/ScriptSrcIO.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/XhrIframeProxy.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/xip_client.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/io/xip_server.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/json.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/array.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/assert.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/declare.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/extras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/func.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/repr.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/timing/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/timing/Streamer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/timing/Timer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lang/type.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/Animation.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/extras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/html.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/rounded.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/shadow.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/lfx/toggle.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/loader.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/loader_xd.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/logging/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/logging/ConsoleLogger.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/logging/Logger.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/math.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/math/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/math/curves.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/math/matrix.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/math/points.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/namespaces/dojo.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/ns.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/profile.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/regexp.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/Deferred.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/JotService.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/JsonService.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/RpcService.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/yahoo.smd		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/rpc/YahooService.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/selection/Selection.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/storage.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/storage/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/storage/browser.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/storage/Storage.as		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/storage/storage_dialog.fla		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/string.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/string/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/string/Builder.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/string/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/string/extras.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/style.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/svg.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/text/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/text/textDirectory.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/undo/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/undo/browser.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/undo/Manager.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uri/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uri/Uri.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/LightweightGenerator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/NameBasedGenerator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/NilGenerator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/RandomGenerator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/TimeBasedGenerator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/uuid/Uuid.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/check.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/common.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/creditCard.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/datetime.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/de.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/jp.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/us.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/validate/web.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/AccordionContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/AnimatedPng.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Button.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Chart.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Checkbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Clock.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ColorPalette.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ComboBox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ContentPane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/CurrencyTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DatePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DateTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DebugConsole.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/DemoContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/DemoItem.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/DemoNavigator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/DemoPane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/SourcePane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoContainer.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoContainer.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoItem.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoItem.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoNavigator.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoNavigator.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoPane.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/DemoPane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/general.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/images/test_thumb.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/images/viewDemo.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/SourcePane.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/demoEngine/templates/SourcePane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Dialog.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DocPane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DomWidget.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DropdownContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DropdownDatePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/DropdownTimePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/AlwaysShowToolbar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/ContextMenu.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/CreateLinkDialog.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/FindReplace.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/FindReplaceDialog.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/InsertImageDialog.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/InsertTableDialog.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/SimpleSignalCommands.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/TableOperation.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Plugin/ToolbarDndSupport.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Editor2Toolbar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/FilteringTable.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/FisheyeList.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/FloatingPane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Form.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/HslColorPicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/html/layout.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/html/loader.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/html/stabile.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/HtmlWidget.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/InlineEditBox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/IntegerTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/InternetTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/LayoutContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/LinkPane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Manager.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Menu2.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/MonthlyCalendar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/DropdownDatePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/DropdownTimePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/fr/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/ja/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/TimePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/nls/zh-cn/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/PageContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Parse.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/PopupContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ProgressBar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/RadioGroup.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/RealNumberTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/RegexpTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/RemoteTabController.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Repeater.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ResizableTextarea.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ResizeHandle.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/RichText.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Rounded.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Select.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Show.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ShowAction.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ShowSlide.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Slider.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SlideShow.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SortableTable.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Spinner.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SplitContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/svg/Chart.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SvgButton.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SvgWidget.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/SwtWidget.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TabContainer.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TaskBar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/AccordionPane.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/AccordionPane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/aggregate.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/backcolor.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/bg-fade.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/bold.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/cancel.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/copy.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/createlink.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/cut.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/delete.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/forecolor.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/hilitecolor.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/indent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/inserthorizontalrule.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/insertimage.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/insertorderedlist.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/inserttable.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/insertunorderedlist.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/italic.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/justifycenter.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/justifyfull.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/justifyleft.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/justifyright.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/left_to_right.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/list_bullet_indent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/list_bullet_outdent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/list_num_indent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/list_num_outdent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/outdent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/paste.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/redo.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/removeformat.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/right_to_left.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/save.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/sep.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/space.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/strikethrough.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/subscript.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/superscript.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/underline.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/undo.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/buttons/wikiword.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ButtonTemplate.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ButtonTemplate.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/check.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Checkbox.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Checkbox.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/CheckboxA11y.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/CiviCrmDatePicker.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ComboBox.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ComboBox.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ComboButtonTemplate.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DatePicker.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DatePicker.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/decrementMonth.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/decrementWeek.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DemoEngine.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Dialog.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DocPane.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DocPane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/DropDownButtonTemplate.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/Dialog/createlink.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/Dialog/find.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/Dialog/insertimage.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/Dialog/inserttable.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/Dialog/replace.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/EditorDialog.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/EditorToolbar_FontName.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/EditorToolbar_FontSize.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/EditorToolbar_FormatBlock.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/showtableborder_gecko.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Editor2/showtableborder_ie.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/EditorToolbar.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/EditorToolbar.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/EditorToolbarOneline.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/FisheyeList.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/FloatingPane.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/FloatingPane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/grabCorner.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/HslColorPicker.svg		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/bar.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/bdYearBg.1.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/bdYearBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/blank.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/clock.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/combo_box_arrow.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dateIcon.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/decrementMonth.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/decrementMonth.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpCurveBL.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpCurveBR.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpCurveTL.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpCurveTR.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpHorizLine.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpHorizLineFoot.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpMonthBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpMonthBg.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpMonthBg2.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpVertLine.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpYearBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dpYearBg.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dropdownButtonsArrow.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/dropdownButtonsArrow-disabled.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/floatingPaneClose.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/floatingPaneMaximize.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/floatingPaneMinimize.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/floatingPaneRestore.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/h-bar.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/hue.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/incrementMonth.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/incrementMonth.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/no.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/no.svg		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/scBackground.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider_down_arrow.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider_left_arrow.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider_right_arrow.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider_up_arrow.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-bg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-bg-progress-vert.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-bg-vert.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-button.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-button-horz.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/slider-button-vert.png		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaAccordionOff.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaAccordionSelected.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaActive-c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaActive-l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaActive-r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaBarBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaButton-c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaButton-l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaButton-r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaDisabled-c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaDisabled-l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaDisabled-r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaMenuBg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaPressed-c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaPressed-l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/soriaPressed-r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/spinnerDecrement.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/spinnerIncrement.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/submenu_disabled.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/submenu_off.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/submenu_on.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_bot_left.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_bot_left_curr.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_bot_right.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_bot_right_curr.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_close.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_close_h.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_left.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_left_r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_left_r_curr.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_right.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_right_r.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_right_r_curr.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_top_left.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/tab_top_right.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/timeIcon.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/toolbar-bg.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/transparent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/blank.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/closed.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/document.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/minus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/plus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/transparent.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/Tree.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_blank.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_child.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_expand_minus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_expand_plus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_p.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_t.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_v.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_x.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_y.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_grid_z.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_loading.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/Tree/treenode_loading.jpg		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_blank.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_child.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_expand_minus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_expand_plus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_c.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_p.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_t.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_v.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_x.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_y.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_grid_z.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/treenode_node.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/closed.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/document.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/expand_leaf.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/expand_loading.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/expand_minus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/expand_plus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/i.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/i_bhalf.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/i_half.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/i_long.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/l.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/minus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/open.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/plus.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/t.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/TreeV3/x.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/verticalbar.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/images/whiteDownArrow.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/incrementMonth.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/incrementWeek.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/InlineEditBox.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/InlineEditBox.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Menu.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Menu2.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/MonthlyCalendar.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/MonthlyCalendar.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/PopUpButton.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ProgressBar.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ProgressBar.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/RemoteTabControl.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ResizableTextarea.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ResizableTextarea.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ResizeHandle.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/richtextframe.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Show.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Show.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ShowSlide.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ShowSlide.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Slider.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Slider.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/SliderHorizontal.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/SliderVertical.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/SlideShow.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/SlideShow.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Spinner.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Spinner.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/SplitContainer.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TabContainer.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TabContainer.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TabContainerA11y.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TaskBar.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TaskBarItemTemplate.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Textbox.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TimePicker.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TimePicker.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TitlePane.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Toaster.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Toolbar.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TooltipTemplate.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Tree.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TreeDisableWrap.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TreeDocIcon.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TreeEditor.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/TreeV3.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Validate.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/ValidationTextbox.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Wizard.css		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/templates/Wizard.html		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Textbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TimePicker.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TitlePane.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Toaster.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Toggler.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Toolbar.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Tooltip.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Tree.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeBasicController.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeBasicControllerV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeCommon.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeContextMenu.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeContextMenuV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeControllerExtension.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeDemo.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeDeselectOnDblselect.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeDisableWrapExtension.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeDndControllerV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeDocIconExtension.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeEditor.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeEmphasizeOnSelect.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeExpandToNodeOnSelect.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeExtension.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeLinkExtension.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeLoadingController.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeLoadingControllerV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeNode.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeNodeV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeRPCController.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeRpcControllerV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeSelector.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeSelectorV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeTimeoutIterator.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeToggleOnSelect.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeV3.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/TreeWithNode.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/UsTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/validate.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/ValidationTextbox.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/vml/Chart.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Widget.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/widget/Wizard.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/xml/__package__.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/xml/Parse.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo/src/xml/XslTransform.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/about.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/dev_domain.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/ibm_com_link.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/iEditAttribute.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/infocenter.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images/onepix.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/filterLayouts/multiFilterLayout.jsp		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/cheatsheet_view.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/collapse_all.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/collapse_expand_all.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/command_prompt.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/complete_task.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/expand_all.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/icon_legend.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/linkto_help.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/quickSearch.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/restart_cheatsheet.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/restart_task.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/skip_task.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/start_cheatsheet.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/start_task.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/images/topic.gif		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/scripts/menu_functions.js		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore/styles/customDojoStyles.jsp		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/de/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/de/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/es/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/es/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/fr/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/fr/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/helpfile.txt		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/it/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/it/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/ja/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/ja/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/ko/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/ko/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/pt_BR/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/pt_BR/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/zh/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/zh/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/zh_TW/doc.zip		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/nl/zh_TW/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes/toc.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_about.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_authenticateAgentAction.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_buttonLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_cheatsheets.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_collectionTableLayout.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_containedContentLayout.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_middlewareNodeCollection.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_pagingLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_removeNode.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes/_selectLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_comboBoxLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_customFilterCollectionTableLayout.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_customPreferencesLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_customQuickSearchLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_customTableControlsLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_inInputLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_portletLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_quickSearch.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_routingRulesLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_ruleActionLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_ruleBuilderLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_ruleBuilderLayoutForHealthPolicy.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_ruleEditLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_ruleLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_selectDynamicLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_textDetailLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_vboxStyleLayout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_xdabout.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/_xdwelcome.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/filterLayouts/_multiFilterLayout.class
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore/styles/_customDojoStyles.class		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/console-defs.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/plugin.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/struts-config.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/struts-config_1_1.dtd		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/tiles-config_1_1.dtd		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo/WEB-INF/web.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/console-defs.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/generated_web.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/ibm-web-ext.xmi		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_de.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_en.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_es.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_fr.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_it.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_ja.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_ko.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_pt.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_pt_BR.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_zh.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/plugin_zh_TW.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/struts-config.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/validation.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes/WEB-INF/web.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/console-defs.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/generated_web.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/ibm-web-bnd.xmi		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/ibm-web-ext.xmi		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_de.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_en.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_es.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_fr.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_it.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_ja.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_ko.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_pt.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_pt_BR.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_zh.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/plugin_zh_TW.properties		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/struts-config.xml		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/struts-config_1_1.dtd		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/tiles-config_1_1.dtd		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore/WEB-INF/web.xml		 		  		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/lib/middlewarenodes-middlewarenodes_module.jar		 		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/lib/xdcore-xdcore_module.jar		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/META-INF/MANIFEST.MF		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/moduleVersion/versioninfo.jsp		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/com/ibm/ws/xdproduct/WelcomePortlet.class		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/moduleVersion/_versioninfo.class		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_de.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_en.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_es.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_fr.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_it.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_ja.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_ko.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_pt.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_pt_BR.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_zh.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/classes/nls/PortletResources_zh_TW.properties		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/ibm-portal-security.xml		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/ibm-portal-topology.xml		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/portlet.xml		 		  
$ConfigRoot/systemApps/isclite.ear/xdportlet.war/WEB-INF/web.xml		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/deployment.xml		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/META-INF/application.xml		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/META-INF/ibm-application-bnd.xmi		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/META-INF/ibm-application-sa.props		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/META-INF/MANIFEST.MF		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/META-INF/was.policy		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/META-INF/MANIFEST.MF		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/classes/com/ibm/ws/xd/agent/webapp/rpc/servlet/MiddlewareAgentRPCServlet$WrappedServletRequest.class
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/classes/com/ibm/ws/xd/agent/webapp/rpc/servlet/MiddlewareAgentRPCServlet$WrappedServletResponse.class
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/classes/com/ibm/ws/xd/agent/webapp/rpc/servlet/MiddlewareAgentRPCServlet.class
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/ibm-web-bnd.xmi		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/ibm-web-ext.xmi		 		  
$ConfigRoot/systemApps/MiddlewareAgentServices.ear/MiddlewareAgentWebapp.war/WEB-INF/web.xml"


echo "+-------------------+"
echo "+    unlink files:  +"
echo "+-------------------+"
for file in $AllFilesToUnlink
do
 echo "unlink $file"
 if [ -L $file ]
   then
     rm $file 
   else
     echo "$file is not a link"
 fi
done
 

AllDirToRm="$ConfigRoot/bin/xd_migration/migrationGUI 
$ConfigRoot/etc/config/xforms/wxdcg 
$ConfigRoot/etc/config/xforms/wxddg
$ConfigRoot/etc/config/xforms/wxdop
$ConfigRoot/etc/config/xforms/xd
$ConfigRoot/etc/config/xforms/xda
$ConfigRoot/firststeps/XD/html 
$ConfigRoot/license.xd 
$ConfigRoot/properties/version/install.xd/
$ConfigRoot/properties/version/nif/componentmaps.xd 		 
$ConfigRoot/properties/version/nif/config.xd
$ConfigRoot/properties/WXD/		  
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.dojo 
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.middlewarenodes/images 
$ConfigRoot/systemApps/isclite.ear/isclite.war/com.ibm.ws.console.xdcore
$ConfigRoot/systemApps/isclite.ear/isclite.war/help/plugins/com.ibm.ws.console.middlewarenodes 
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_middlewarenodes 		 
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/classes/_ibmjsp/com_2E_ibm_2E_ws_2E_console_2E_xdcore 		 
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.dojo 
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.middlewarenodes 		 
$ConfigRoot/systemApps/isclite.ear/isclite.war/WEB-INF/com.ibm.ws.console.xdcore 
$ConfigRoot/systemApps/isclite.ear/xdportlet.war
$ConfigRoot/systemApps/MiddlewareAgentServices.ear
$ConfigRoot/properties/service/product/WebSphereXD"

echo "+-------------------+"
echo "+ remove directory  +"
echo "+-------------------+"
for args in $AllDirToRm
do 
 if [ -d $args ]
    then
      rm -rf $args
      echo "remove $args"
    else 
     echo "$args does not exist"
 fi

done

echo "All of the XD Base component has been unlinked and removed"

exit 0 


